"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var TransferModule_1, TransferModuleForUnitTest_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferModuleForUnitTest = exports.TransferModule = void 0;
const origin_247_certificate_1 = require("@energyweb/origin-247-certificate");
const common_1 = require("@nestjs/common");
const cqrs_1 = require("@nestjs/cqrs");
const typeorm_1 = require("@nestjs/typeorm");
const GenerationReadingStoredEvent_handler_1 = require("./handlers/GenerationReadingStoredEvent.handler");
const repositories_1 = require("./repositories");
const transfer_service_1 = require("./transfer.service");
const ValidateTransferCommand_1 = require("./commands/ValidateTransferCommand");
const UpdateTransferValidationCommand_handler_1 = require("./handlers/UpdateTransferValidationCommand.handler");
const validate_service_1 = require("./validate.service");
const issue_service_1 = require("./issue.service");
const validate_batch_1 = require("./batch/validate.batch");
const transfer_batch_1 = require("./batch/transfer.batch");
const issue_batch_1 = require("./batch/issue.batch");
const configuration_1 = require("./batch/configuration");
const lodash_1 = require("lodash");
const batchHandlers = [
    validate_batch_1.AwaitingValidationEventHandler,
    transfer_batch_1.AwaitingTransferEventHandler,
    issue_batch_1.AwaitingIssuanceEventHandler
];
const integrationHandlers = [
    GenerationReadingStoredEvent_handler_1.GenerationReadingStoredEventHandler,
    UpdateTransferValidationCommand_handler_1.UpdateTransferValidationCommandHandler
];
const services = [transfer_service_1.TransferService, issue_service_1.IssueService, validate_service_1.ValidateService];
let TransferModule = TransferModule_1 = class TransferModule {
    static register(params) {
        return {
            module: TransferModule_1,
            providers: [
                ...services,
                ...integrationHandlers,
                ...batchHandlers,
                {
                    provide: repositories_1.ENERGY_TRANSFER_REQUEST_REPOSITORY,
                    useClass: repositories_1.EnergyTransferRequestPostgresRepository
                },
                {
                    provide: ValidateTransferCommand_1.VALIDATE_TRANSFER_COMMANDS_TOKEN,
                    useValue: params.validateCommands
                },
                {
                    provide: configuration_1.BATCH_CONFIGURATION_TOKEN,
                    useValue: lodash_1.defaults(params.batchConfiguration ?? {}, configuration_1.defaultBatchConfiguration)
                }
            ],
            imports: [
                typeorm_1.TypeOrmModule.forFeature([repositories_1.EnergyTransferRequestEntity]),
                cqrs_1.CqrsModule,
                origin_247_certificate_1.OffChainCertificateModule
            ]
        };
    }
};
TransferModule = TransferModule_1 = __decorate([
    common_1.Module({})
], TransferModule);
exports.TransferModule = TransferModule;
let TransferModuleForUnitTest = TransferModuleForUnitTest_1 = class TransferModuleForUnitTest {
    static register(params) {
        return {
            module: TransferModuleForUnitTest_1,
            providers: [
                ...services,
                ...integrationHandlers,
                ...batchHandlers,
                {
                    provide: repositories_1.ENERGY_TRANSFER_REQUEST_REPOSITORY,
                    useClass: repositories_1.EnergyTransferRequestInMemoryRepository
                },
                {
                    provide: ValidateTransferCommand_1.VALIDATE_TRANSFER_COMMANDS_TOKEN,
                    useValue: params.validateCommands
                },
                {
                    provide: configuration_1.BATCH_CONFIGURATION_TOKEN,
                    useValue: lodash_1.defaults(params.batchConfiguration ?? {}, configuration_1.defaultBatchConfiguration)
                }
            ],
            imports: [cqrs_1.CqrsModule, origin_247_certificate_1.OffChainCertificateForUnitTestsModule.register()]
        };
    }
};
TransferModuleForUnitTest = TransferModuleForUnitTest_1 = __decorate([
    common_1.Module({})
], TransferModuleForUnitTest);
exports.TransferModuleForUnitTest = TransferModuleForUnitTest;
//# sourceMappingURL=transfer.module.js.map